const appRootDir = require('app-root-dir');
const gulp = require('gulp');
const Karma = require('karma');

const basePath = appRootDir.get();

const testFiles = basePath + '/test/**/*.spec.js';

gulp.task('extension:test', function () {
  const preprocessors = {};

  preprocessors[testFiles] = 'webpack';

  const server = new Karma.Server({
    frameworks: [
      'mocha',
      'chai',
      'sinon'
    ],
    files: [
      testFiles,
    ],
    browsers: ['ChromeHeadless'],
    reporters: ['mocha'],
    singleRun: true,
    preprocessors: preprocessors,

    webpack: {
      module: {
        rules: [
          {
            test: /\.js$/,
            exclude: /(node_modules|bower_components)/,
            include: /(node_modules\/xethya-extension)/,
            use: {
              loader: 'babel-loader',
              options: {
                presets: ['@babel/preset-env'],
                plugins: [
                  require('@babel/plugin-proposal-decorators'),
                  require('@babel/plugin-external-helpers'),
                  require('@babel/plugin-transform-runtime')
                ]
              }
            }
          }
        ]
      },
    },

    webpackMiddleware: {
      noInfo: true,
      stats: 'errors-only',
    },
  });

  server.start();
});
