import { Assertable, assert } from '../../src/extension';

@Assertable
class WithAssertions {
  constructor() {

  }

  useNumber(num) {
    this.assert(typeof num === 'number', 'num must be a Number');
  }

  static useString(str) {
    assert(typeof str === 'string', 'str must be a String');
  }
}

describe('#Traits.Assertable', () => {
  it('should throw an AssertionError when an assertion fails', () => {
    expect(() => {
      new WithAssertions().useNumber("?");
    }).to.throw(/AssertionError.+num must be a Number/);
  });
  it('should do nothing when an assertion passes', () => {
    expect(() => {
      new WithAssertions().useNumber(4);
    }).to.not.throw(/AssertionError/);
  });
  it('should expose the stand-alone function', () => {
    expect(assert).to.be.an.instanceof(Function);
  });
  it('should work with the stand-alone function for static scopes', () => {
    expect(() => {
      WithAssertions.useString(28);
    }).to.throw(/AssertionError.+str must be a String/);
    expect(() => {
      WithAssertions.useString('28');
    }).to.not.throw(/AssertionError/);
  });
});
