import { Assertable, Eventable } from '../../src/extension';

@Eventable
class WithEvents {
  constructor(onEvent) {
    this.on('event', onEvent);
  }

  doSomething() {
    return true;
  }
}

@Assertable
@Eventable
class AssertableWithEvents {
  constructor(onEvent) {
    this.assert(onEvent instanceof Function);
    this.on('event', onEvent);
  }
}


describe('#Traits.Eventable', () => {
  it('should trigger events', (done) => {
    const onEventDone = () => {
      done();
    };

    const withEvents = new WithEvents(onEventDone);

    withEvents.emit('event');
  });
  it('should live happily with other traits', (done) => {
    const onEventDone = () => {
      done();
    };

    const withEvents = new AssertableWithEvents(onEventDone);

    withEvents.emit('event');
  });
  it('should preserve the class prototype', () => {
    const onEventDone = () => {};

    const withEvents = new WithEvents(onEventDone);

    expect(withEvents.doSomething()).to.be.true;
  });
});
